@@ -11,14 +11,52 @@ from asyncio import iscoroutinefunction
 from http.cookies import SimpleCookie
 from typing import Any, Callable, Dict, List, Mapping, Text, Union
 
+import httpx
 from aiohttp import ClientResponse
-from multidict import MultiDict
+from multidict import MultiDict, MultiDictProxy
 from yarl import URL
 
 _LOGGER = logging.getLogger(__name__)
 
 
-def print_resp(resp: ClientResponse) -> None:
+def print_resp(resp: Union[httpx.Response, ClientResponse]) -> None:
+    """Print response info.
+
+    Args:
+        resp (httpx.Response): The client response to show
+
+    Returns:
+        None
+    """
+    if not isinstance(resp, httpx.Response):
+        return print_resp_aiohttp(resp)
+    if resp.history:
+        for item in resp.history:
+            _LOGGER.debug("%s: redirected from\n%s", item.request.method, item.url)
+    url = resp.request.url
+    method = resp.request.method
+    status = resp.status_code
+    reason = resp.reason_phrase
+    headers = ast.literal_eval(str(resp.request.headers)[8:-1])
+    cookies = {}
+    if headers.get("cookie"):
+        cookie: SimpleCookie = SimpleCookie()
+        cookie.load(headers.get("cookie"))
+        for key, morsel in cookie.items():
+            cookies[key] = morsel.value
+        headers["cookie"] = cookies
+    _LOGGER.debug(
+        "%s: \n%s with\n%s\nreturned %s:%s with response %s",
+        method,
+        url,
+        json.dumps(headers),
+        status,
+        reason,
+        resp.headers,
+    )
+
+
+def print_resp_aiohttp(resp: ClientResponse) -> None:
     """Print response info.
 
     Args:
@@ -195,3 +233,49 @@ def get_nested_dict_keys(
         else:
             result.append(key)
     return result
+
+
+def get_content_type(resp: httpx.Response) -> str:
+    """Get content_type from httpx Response.
+
+    Args:
+        resp (httpx.Response): Response from httpx request
+
+    Returns:
+        str: The content_type
+    """
+    content_type = ""
+    content_type_string = resp.headers.get("content-type")
+    if content_type_string and ";" in content_type_string:
+        content_type = content_type_string.split(";")[0].strip()
+    elif content_type_string:
+        content_type = content_type_string
+    return content_type
+
+
+def convert_multidict_to_dict(
+    multidict: Union[MultiDict, MultiDictProxy], flat: bool = False
+) -> dict:
+    """Convert a multdict to a dict for httpx.
+
+    https://www.python-httpx.org/quickstart/#sending-form-encoded-data
+
+    Args:
+        multidict (MultiDict | MultiDictProxy): The multidict to convert
+        flat (bool): whether to create a list for duplicates or keep last
+
+    Returns:
+        dict: A dictionary where duplicate keys will be added as a list or flattened
+    """
+    result: dict = {}
+    for k, v in multidict.items():
+        old_value = result.get(k)
+        if old_value and not flat:
+            list_value = []
+            if not isinstance(old_value, list):
+                list_value.append(old_value)
+            list_value.append(v)
+            result[k] = list_value
+        else:
+            result[k] = v
+    return result
